Method: Console::Event::Failure.default_root
- Defined in:
- lib/console/event/failure.rb
.default_root ⇒ Object
For the purpose of efficiently formatting backtraces, we need to know the root directory of the project.
27 28 29 30 31 |
# File 'lib/console/event/failure.rb', line 27 def self.default_root Dir.getwd rescue # e.g. Errno::EMFILE nil end |